# Generated by roxygen2: do not edit by hand

S3method("$",cube)
S3method("[",cube)
S3method(apply_pixel,array)
S3method(apply_pixel,cube)
S3method(apply_time,array)
S3method(apply_time,cube)
S3method(as.data.frame,cube)
S3method(dim,cube)
S3method(names,cube)
S3method(plot,cube)
S3method(predict,cube)
S3method(print,cube)
S3method(print,cube_view)
S3method(print,image_collection)
S3method(reduce_space,array)
S3method(reduce_space,cube)
S3method(reduce_time,array)
S3method(reduce_time,cube)
export(add_collection_format)
export(add_images)
export(aggregate_space)
export(aggregate_time)
export(animate)
export(apply_pixel)
export(apply_time)
export(as_array)
export(as_json)
export(bands)
export(chunk_apply)
export(collection_formats)
export(create_image_collection)
export(crop)
export(cube_view)
export(dimension_bounds)
export(dimension_values)
export(dimensions)
export(extent)
export(extract_geom)
export(fill_time)
export(filter_geom)
export(filter_pixel)
export(gdalcubes_gdal_has_geos)
export(gdalcubes_gdalformats)
export(gdalcubes_gdalversion)
export(gdalcubes_options)
export(gdalcubes_set_gdal_config)
export(image_collection)
export(image_mask)
export(join_bands)
export(json_cube)
export(memsize)
export(nbands)
export(ncdf_cube)
export(nt)
export(nx)
export(ny)
export(pack_minmax)
export(proj4)
export(raster_cube)
export(read_chunk_as_array)
export(reduce_space)
export(reduce_time)
export(rename_bands)
export(select_bands)
export(select_time)
export(size)
export(slice_space)
export(slice_time)
export(srs)
export(st_as_stars.cube)
export(stac_image_collection)
export(stack_cube)
export(window_space)
export(window_time)
export(write_chunk_from_array)
export(write_ncdf)
export(write_tif)
import(jsonlite)
import(ncdf4)
importFrom(Rcpp,sourceCpp)
importFrom(grDevices,col2rgb)
importFrom(grDevices,dev.capabilities)
importFrom(grDevices,dev.off)
importFrom(grDevices,dev.size)
importFrom(grDevices,grey)
importFrom(grDevices,png)
importFrom(grDevices,rainbow)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,image.default)
importFrom(graphics,layout)
importFrom(graphics,lcm)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,rasterImage)
importFrom(graphics,rect)
importFrom(graphics,title)
importFrom(stats,complete.cases)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(utils,download.file)
importFrom(utils,head)
importFrom(utils,object.size)
useDynLib(gdalcubes)
